# lynxius-python client
Lynxius Web App offers advanced AI observability features, security, scalability, integrations with existing ecosystems and easy collaboration across teams.


:warning::warning::warning: If you've landed on this page, you're likely participating in our closed beta program for [Lynxius](https://www.lynxius.ai/) and are already aware that this page serves as a placeholder. We are on the brink of officially launching our platform along with detailed documentation. In the meantime, here are a few code examples. :warning::warning::warning:

## Lynxius Platform in 3 Minutes
[![Video Thumbnail](https://github-public-assets.s3.us-west-1.amazonaws.com/chatdoctorv2_datasetv2labeled.png)](https://github-public-assets.s3.us-west-1.amazonaws.com/Lynxius+Demo.mp4)



## Code Examples

Checkout our tutorials:

1. [Lynxius to evaluate LLM Summarization and Custom Metrics](./tutorials/AI_medical_scribe_with_UI.ipynb)
2. [Lynxius to evaluate LLM chatbot applications](./tutorials/ChatDoctor.ipynb)
3. [Lynxius to boost collaboration with Subject Matter Experts](./tutorials/Datasets.ipynb)

## Create a Development Environment

For local development, start by installing python `3.12.1`, creating a virtual environment and installing the dependencies:

```bash
python3.12 -m venv .lynxius-python
source .lynxius-python/bin/activate
pip install -r requirements.txt
```